==> humhub-1.11.0-beta.2.tar.gz: humhub-1.11.0-beta.2/protected/humhub/modules/admin/messages/pl/information.php <==
<?php
return array (
  '<strong>CronJob</strong> Status' => 'Stan <strong>CronJob</strong>',
  '<strong>Queue</strong> Status' => 'Stan <strong>Kolejki</strong>',
  'About HumHub' => 'O HumHub',
  'Assets' => 'Zasoby',
  'Background Jobs' => 'Zadania w tle',
  'Checking HumHub software prerequisites.' => 'Sprawdzanie wstępnych wymagań oprogramowania HumHub.',
  'Current limit is: {currentLimit}' => 'Obecny limit wynosi: {currentLimit}',
  'Database' => 'Baza danych',
  'Database collation' => 'Sortowanie bazy danych',
  'Database connection time: {dbTime} - Configured time zone: {time}' => 'Czas połączenia z bazą danych: {dbTime} - Ustawiona strefa czasowa: {time}',
  'Database driver - {driver}' => 'Sterownik bazy danych - {driver}',
  'Database migration results:' => 'Wynik migracji bazy danych:',
  'Delayed' => 'Opóźnione',
  'Displaying {count} entries per page.' => 'Pokazano {count} wpisów na stronę.',
  'Done' => 'Zakończone',
  'Driver' => 'Sterownik',
  'Dynamic Config' => 'Ustawienia dynamiczne',
  'Error' => 'Błąd',
  'Flush entries' => 'Wyczyść wpisy',
  'HumHub is currently in debug mode. Disable it when running on production!' => 'HumHub jest w trybie debugowania. Wyłącz go gdy udostępnisz stronę użytkownikom!',
  'ICU Data Version ({version})' => '',
  'ICU Data {icuMinVersion} or higher is required' => '',
  'ICU Version ({version})' => '',
  'ICU {icuMinVersion} or higher is required' => '',
  'Increase memory limit in {fileName}' => 'Zwiększ limit pamięci w {fileName}',
  'Info' => 'Informacje',
  'Install {phpExtension} Extension' => 'Zainstaluj rozszerzenie {phpExtension}',
  'Install {phpExtension} Extension for APC Caching' => 'Zainstaluj rozszerzenie {phpExtension} do APC Caching\'u',
  'Install {phpExtension} Extension for DB Caching' => 'Zainstaluj rozszerzenie {phpExtension} do cache\'u Bazy Danych',
  'Install {phpExtension} Extension for e-mail S/MIME support.' => 'Zainstaluj rozszerzenie {phpExtension} do wsparcia e-mail S/MIME',
  'Last run (daily):' => 'Ostatnie uruchomienie (dzienne):',
  'Last run (hourly):' => 'Ostatnie uruchomienie (godzinowe):',
  'Licences' => 'Licencje',
  'Logging' => 'Logowanie',
  'Make {filePath} writable for the Webserver/PHP!' => 'Ustaw {filePath} możliwą do zapisu dla serwera/PHP!',
  'Memory Limit ({memoryLimit})' => 'Limit pamięci ({memoryLimit})',
  'Minimum Version {minVersion}' => 'Minimalna Wersja {minVersion}',
  'Module Directory' => 'Katalog Modułów',
  'Multibyte String Functions' => '',
  'Never' => 'Nigdy',
  'Optional' => 'Opcjonalne',
  'Other' => 'Inne',
  'Permissions' => 'Uprawnienia',
  'Please refer to the documentation to setup the cronjobs and queue workers.' => 'Proszę odnieść się do dokumentacji w celu ustawienia zadań cron i kolejki działań.',
  'Prerequisites' => 'Wymagania',
  'Profile Image' => 'Obraz profilowy',
  'Queue successfully cleared.' => 'Kolejka wyczyszczona prawidłowo',
  'Re-Run tests' => 'Uruchom ponownie testy',
  'Recommended collation is {collation}' => 'Zalecane sortowanie to {collation}',
  'Recommended collation is {collation} for the tables: {tables}' => 'Zalecane sortowanie to {collation} dla tabel: {tables}',
  'Recommended engine is {engine} for the tables: {tables}' => 'Zalecany silnik to {engine} dla tabel: {tables}',
  'Reserved' => 'Zarezerwowane',
  'Runtime' => 'Czas uruchomienia',
  'Search index rebuild in progress.' => 'Indeks szukania przebudowany prawidłowo.',
  'Search term...' => 'Szukana fraza...',
  'See installation manual for more details.' => 'Więcej informacji znajdziesz w instrukcji instalacji.',
  'Select category..' => 'Wybierz kategorię...',
  'Select day' => 'Wybierz dzień',
  'Select level...' => 'Wybierz poziom...',
  'Settings' => 'Ustawienia',
  'Supported drivers: {drivers}' => 'Wspierane sterowniki: {drivers}',
  'Table collations' => 'Sortowanie tabel',
  'Table engines' => 'Silniki tabel',
  'The current main HumHub database name is ' => 'Obecna nazwa głównej bazy danych HumHub to:',
  'There is a new update available! (Latest version: %version%)' => 'Dostępna jest aktualizacja! (Najnowsza wersja: %version%)',
  'This HumHub installation is up to date!' => 'Ta instalacja HumHuba jest aktualna!',
  'Time zone' => 'Strefa czasowa',
  'Total {count} entries found.' => 'W sumie znaleziono {count} wpisów.',
  'Trace' => 'Ślad',
  'Uploads' => 'Wgrane pliki',
  'Varying table engines are not supported.' => 'Różne sortowanie silników tabel nie jest obsługiwane',
  'Version' => 'Wersja',
  'Waiting' => 'Oczekiwanie',
  'Warning' => 'Ostrzeżenie',
  '{imageExtension} Support' => 'Wsparcie dla {imageExtension}',
  '{phpExtension} Extension' => 'Rozszerzenie {phpExtension}',
  '{phpExtension} Support' => 'Wsparcie dla {phpExtension}',
);

==> humhub-1.15.0-beta.2.tar.gz: humhub-1.15.0-beta.2/protected/humhub/modules/admin/messages/pl/information.php <==
<?php
return array (
  '<strong>CronJob</strong> Status' => 'Stan <strong>CronJob</strong>',
  '<strong>Queue</strong> Status' => 'Stan <strong>Kolejki</strong>',
  'About HumHub' => 'O HumHub',
  'Assets' => 'Zasoby',
  'Background Jobs' => 'Zadania w tle',
  'Base URL' => 'Główny URL',
  'Checking HumHub software prerequisites.' => 'Sprawdzanie wstępnych wymagań oprogramowania HumHub.',
  'Current limit is: {currentLimit}' => 'Obecny limit wynosi: {currentLimit}',
  'Database' => 'Baza danych',
  'Database collation' => 'Sortowanie bazy danych',
  'Database connection time: {dbTime} - Configured time zone: {time}' => 'Czas połączenia z bazą danych: {dbTime} - Ustawiona strefa czasowa: {time}',
  'Database driver - {driver}' => 'Sterownik bazy danych - {driver}',
  'Database migration results:' => 'Wynik migracji bazy danych:',
  'Delayed' => 'Opóźnione',
  'Detected URL: {currentBaseUrl}' => '',
  'Disabled Functions' => 'Funkcje wyłączone',
  'Displaying {count} entries per page.' => 'Pokazano {count} wpisów na stronę.',
  'Done' => 'Zakończone',
  'Driver' => 'Sterownik',
  'Dynamic Config' => 'Ustawienia dynamiczne',
  'Error' => 'Błąd',
  'Flush entries' => 'Wyczyść wpisy',
  'HumHub' => 'HumHub',
  'HumHub Documentation' => 'Dokumentacja HumHub',
  'HumHub is currently in debug mode. Disable it when running on production!' => 'HumHub jest w trybie debugowania. Wyłącz go gdy udostępnisz stronę użytkownikom!',
  'ICU Data Version ({version})' => 'Wersja Danych ICU ({version})',
  'ICU Data {icuMinVersion} or higher is required' => 'Wersja Danych ICU  {icuMinVersion} lub wyższa jest wymagana',
  'ICU Version ({version})' => 'Wersja ICU  ({version})',
  'ICU {icuMinVersion} or higher is required' => 'ICU wersja {icuMinVersion} lub wyższa jest wymagana',
  'Increase memory limit in {fileName}' => 'Zwiększ limit pamięci w {fileName}',
  'Info' => 'Informacje',
  'Install {phpExtension} Extension' => 'Zainstaluj rozszerzenie {phpExtension}',
  'Install {phpExtension} Extension for APC Caching' => 'Zainstaluj rozszerzenie {phpExtension} do APC Caching\'u',
  'Install {phpExtension} Extension for DB Caching' => 'Zainstaluj rozszerzenie {phpExtension} do cache\'u Bazy Danych',
  'Install {phpExtension} Extension for e-mail S/MIME support.' => 'Zainstaluj rozszerzenie {phpExtension} do wsparcia e-mail S/MIME',
  'Last run (daily):' => 'Ostatnie uruchomienie (dzienne):',
  'Last run (hourly):' => 'Ostatnie uruchomienie (godzinowe):',
  'Licences' => 'Licencje',
  'Logging' => 'Logowanie',
  'Make sure that the `proc_open` function is not disabled.' => 'Upewnij się, że funkcja `proc_open` jest wyłączona.',
  'Make {filePath} writable for the Webserver/PHP!' => 'Ustaw {filePath} możliwą do zapisu dla serwera/PHP!',
  'Marketplace API Connection' => '',
  'Memory Limit ({memoryLimit})' => 'Limit pamięci ({memoryLimit})',
  'Minimum Version {minVersion}' => 'Minimalna Wersja {minVersion}',
  'Module Directory' => 'Katalog Modułów',
  'Multibyte String Functions' => 'Funkcje Ciągu znaków Multibyte',
  'Never' => 'Nigdy',
  'Optional' => 'Opcjonalne',
  'Other' => 'Inne',
  'Permissions' => 'Uprawnienia',
  'Please refer to the documentation to setup the cronjobs and queue workers.' => 'Proszę odnieść się do dokumentacji w celu ustawienia zadań cron i kolejki działań.',
  'Prerequisites' => 'Wymagania',
  'Pretty URLs' => '',
  'Profile Image' => 'Obraz profilowy',
  'Queue successfully cleared.' => 'Kolejka wyczyszczona prawidłowo',
  'Re-Run tests' => 'Uruchom ponownie testy',
  'Recommended collation is {collation}' => 'Zalecane sortowanie to {collation}',
  'Recommended collation is {collation} for the tables: {tables}' => 'Zalecane sortowanie to {collation} dla tabel: {tables}',
  'Recommended engine is {engine} for the tables: {tables}' => 'Zalecany silnik to {engine} dla tabel: {tables}',
  'Reserved' => 'Zarezerwowane',
  'Runtime' => 'Czas uruchomienia',
  'Search index rebuild in progress.' => 'Indeks szukania przebudowany prawidłowo.',
  'Search term...' => 'Szukana fraza...',
  'See installation manual for more details.' => 'Więcej informacji znajdziesz w instrukcji instalacji.',
  'Select category..' => 'Wybierz kategorię...',
  'Select day' => 'Wybierz dzień',
  'Select level...' => 'Wybierz poziom...',
  'Settings' => 'Ustawienia',
  'Supported drivers: {drivers}' => 'Wspierane sterowniki: {drivers}',
  'Table collations' => 'Sortowanie tabel',
  'Table engines' => 'Silniki tabel',
  'The current main HumHub database name is ' => 'Obecna nazwa głównej bazy danych HumHub to:',
  'There is a new update available! (Latest version: %version%)' => 'Dostępna jest aktualizacja! (Najnowsza wersja: %version%)',
  'This HumHub installation is up to date!' => 'Ta instalacja HumHuba jest aktualna!',
  'Time zone' => 'Strefa czasowa',
  'Total {count} entries found.' => 'W sumie znaleziono {count} wpisów.',
  'Trace' => 'Ślad',
  'Uploads' => 'Wgrane pliki',
  'Varying table engines are not supported.' => 'Różne sortowanie silników tabel nie jest obsługiwane',
  'Version' => 'Wersja',
  'Waiting' => 'Oczekiwanie',
  'Warning' => 'Ostrzeżenie',
  '{imageExtension} Support' => 'Wsparcie dla {imageExtension}',
  '{phpExtension} Extension' => 'Rozszerzenie {phpExtension}',
  '{phpExtension} Support' => 'Wsparcie dla {phpExtension}',
);
